<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM;

use DM\Service;
use DM\Demo;
use DM\Config;

class Manager
{
    protected $local = null;
    protected $remoute = null;
    protected $installed = null;
    protected $theme_name = null;
    protected $remove_data = null;
    protected $local_data = null;
    protected $install_data = null;
    private static $_instance = null;
    
    const LOCAL = 'local';
    const INSTALLED = 'installed';
    const REMOUTE = 'remoute';
    
    /**
     * @return \DM\Manager
     */
    static public function getInstance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        
        return self::$_instance;
    }
    
    private function __construct()
    {
        $this->theme_name = wp_get_theme();
    }
    
    public function getDemosCount($type, $required_current_theme = null)
    {
        return count($this->getDemos($type), $required_current_theme);
    }
    
    public function getDemos($type, $required_current_theme = null)
    {
        $Collection = $this->getCollections($type);
        if (is_null($required_current_theme)) {
            return $Collection;
        }
        
        $result = array();
        if ($required_current_theme === true) {
            foreach ($Collection as $demo) {
                if ($demo->isCurrentThemeDemo() === true) {
                    $result[] = $demo;
                }
            }
        } else {
            foreach ($Collection as $demo) {
                if ($demo->isCurrentThemeDemo() === false) {
                    $result[] = $demo;
                }
            }
        }
        
        return $result;
    }
    
    public function getDemosTags($Demos)
    {
        $all_tags = array();
        foreach ($Demos as $demo) {
            if ($tags = $demo->getTags()) {
                $all_tags = array_merge(explode(',', $tags), $all_tags);
            }
        }
        
        return array_unique($all_tags);
    }
    
    /**
     * @param string $type
     * @return \DM\Demo
     */
    public function getCollections($type)
    {
        if (!is_null($this->$type)) {
            return $this->$type;
        }
        
        $data = array();
        if ($type === 'remoute') {
            $data = $this->getRemouteDemosDatas();
        } else if ($type === 'local') {
            $data = $this->getLocalDemosDatas();
        } else if ($type === 'installed') {
            $data = $this->getInstalledDemosDatas();
        } else {
            return array();
        }
        
        if (!$data || !is_array($data)) {
            return array();
        }
        
        $result = array();
        foreach ($data as $demo_config) {
            $demo_config['version'] = $type;
            $result[] = new Demo($demo_config);
        }
        
        $this->$type = $result;
        return $this->$type;
    }
    
    public function getByGlobalId($global_id)
    {
        list($type, $id) = explode('&', $global_id);
        return $this->getById($id, $type);
    }
    
    public function initDemoByGlobalId($global_id)
    {
        if (!is_string($global_id) && strlen($global_id) < 1) {
            throw new \Exception('Incorrent demo identety');
        }
        
        list($type, $id) = explode('&', $global_id);
        $Demo = $this->getById($id, $type);
        if ($Demo) {
            return $Demo;
        }
        
        $origin_demo_id = Data::getActivateDemo();
        $OriginDemo = $this->getById($origin_demo_id, 'installed');
        $NewDemo = new Demo($OriginDemo->toArray());
        $NewDemo->setId($global_id);
        return $NewDemo;
    }
    
    /**
     * 
     * @param string $id
     * @param string $type
     * @return \DM\Demo
     */
    public function getById($id, $type)
    {
        foreach ($this->getCollections($type) as $demo) {
            if ($demo->getId() == $id) {
                return $demo;
            }
        }
        
        return false;
    }
    
    // Demo datas
    
    public function getRemouteDemosDataById($id)
    {
        $data = $this->getRemouteDemosDatas();
        foreach ($data as $demo) {
            if ($demo['id'] === $id) {
                return $demo;
            }
        }
        
        return false;
    }
    
        protected function getRemouteDemosDatas()
        {
            if (!is_null($this->remove_data)) {
                return $this->remove_data;
            }

            $json = wp_remote_get(Config::getInstance()->getRepositoryCollectionUrl());
            if ($json instanceof \WP_Error || !isset($json['body']) || !$json['body']) {
                //throw new \Exception('Remote repository is temporarily unavailable.');
                $this->remove_data = array();
                return $this->remove_data;
            }

            $this->remove_data = json_decode($json['body'], true);
            return $this->remove_data;
        }
    
    public function getLocalDemosDataById($id)
    {
        $data = $this->getLocalDemosDatas();
        foreach ($data as $demo) {
            if ($demo['id'] === $id) {
                return $demo;
            }
        }
        
        return false;
    }
    
    public function hasLocalDemos()
    {
        if (count($this->getLocalDemosDatas())) {
            return true;
        }
        
        return false;
    }
    
        protected function getLocalDemosDatas()
        {
            if (!is_null($this->local_data)) {
                return $this->local_data;
            }

            $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();

            $result = array();
            $dir_path = Config::getInstance()->getDemosDir();
            $files_list = $wp_filesystem->dirlist(Config::getInstance()->getDemosDir());
            if (!$files_list) {
                return $result;
            }
            
            foreach ($files_list as $file_name => $details) {
                $demo_dir_path = $dir_path . $file_name . '/' . 'config.json';
                if ($wp_filesystem->is_file($demo_dir_path)) {
                    $json_config = $wp_filesystem->get_contents($demo_dir_path);
                    $result[] = json_decode($json_config, true);
                }
            }

            $this->local_data = $result;
            return $this->local_data;
        }
    
    public function hasInstalledDemos()
    {
        if (count($this->getInstalledDemosDatas())) {
            return true;
        }
        
        return false;
    }
    
        protected function getInstalledDemosDatas()
        {
            if (!is_null($this->install_data)) {
                return $this->install_data;
            }
            global $wpdb;

            $result = array();
            $db_tables = $wpdb->get_col("SHOW TABLES;");
            foreach ($db_tables as $table_name) {
                if (strpos($table_name, 'options') !== false) {
                    $demo_id = str_replace('options', '', $table_name);

                    // Нужно вытянуть данные из базы
                    $result[] = Service::getInstalledDemoData($demo_id);
                }
            }

            $this->install_data = $result;
            return $this->install_data;
        }
}

