<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM\Pages;

use DM\WPObjects\Page\AdminPage;
use DM\Service;
use DM\Config;
use DM\Log;

class DemoManager extends AdminPage
{
    public function __construct()
    {
        $this->menu_name = __( 'Demo Yükleyici', 'dm-admin' );
        $this->title = __( 'Demo Yükleyici', 'dm-admin' );
        $this->permission = 'manage_options';
        $this->id = 'dm_demo_manager';
        $this->icon_url = plugins_url() . '/wp_demo_manager/assets/images/dm_logo_menu.png';
    }
    
    public function getTemplatePath()
    {
        return WP_DEMO_MANAGER_PATH . 'includes/templates/demo_manager.php';
    }
    
    public function render()
    {
        try {
            //Create log files if not exists
            Log::getFilePath();
            
            parent::render();
        } catch (\Exception $ex) {
            $message = $ex->getMessage();
            include(WP_DEMO_MANAGER_PATH . 'includes/templates/demo_manager_error.php');
        }
    }
    
    public function enqueues()
    {
        wp_enqueue_style('dm_bootstrap_wrapper', plugins_url() . '/wp_demo_manager/assets/css/bootstrap-wrapper.css', false, false, 'all');
        wp_enqueue_style('dm_admin_default', plugins_url() . '/wp_demo_manager/assets/css/admin-defaults.css', false, false, 'all');
        wp_enqueue_style('dm_fontawesome', plugins_url() . '/wp_demo_manager/assets/css/font-awesome.min.css', false, false, 'all');
        wp_enqueue_style('dm_style', plugins_url() . '/wp_demo_manager/assets/css/style.css', false, false, 'all');
        
        wp_enqueue_script('isotope', plugins_url() . '/wp_demo_manager/assets/js/vendor/isotope.min.js', array('jquery'), false, 'all');
        wp_enqueue_script('imagesloaded', plugins_url() . '/wp_demo_manager/assets/js/vendor/imagesloaded.pkgd.min.js', array('isotope'), false, 'all');
        wp_enqueue_script('bootstrap', plugins_url() . '/wp_demo_manager/assets/js/vendor/bootstrap.min.js', array('jquery'), '3.3.7', 'all');
        wp_enqueue_script('dm_script', plugins_url() . '/wp_demo_manager/assets/js/js.js', array('backbone', 'jquery', 'isotope', 'bootstrap'), false, 'all');
        wp_localize_script('dm_script', 'wp_demo_manager', array(
            'log_url' => Config::getInstance()->getLogUrl(),
            'data_key' => Service::getDBname(),
            'ajax_url' => \admin_url( 'admin-ajax.php' )
        ));
        
        wp_register_script('dm_model.status', plugins_url() . '/wp_demo_manager/assets/js/mvc/model/status.js', array('dm_script'), false, 'all');
        wp_register_script('dm_view.demo',  plugins_url() . '/wp_demo_manager/assets/js/mvc/view/demo.js', array('dm_script'), false, 'all');
        wp_register_script('dm_view.progress',  plugins_url() . '/wp_demo_manager/assets/js/mvc/view/progress.js', array('dm_script'), false, 'all');
        wp_register_script('dm_view.process',  plugins_url() . '/wp_demo_manager/assets/js/mvc/view/process.js', array('dm_script'), false, 'all');
        wp_register_script('dm_view.processing-help',  plugins_url() . '/wp_demo_manager/assets/js/mvc/view/processing-help.js', array('dm_script'), false, 'all');
        
        wp_enqueue_script('dm_processing', plugins_url() . '/wp_demo_manager/assets/js/processing.js', array(
            'dm_view.demo', 
            'dm_view.progress', 
            'dm_view.process', 
            'dm_model.status',
            'dm_view.processing-help'
        ), false, 'all');
    }
    
    public function POSTAction($data)
    {
        global $_FILES;
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        
        if (!isset($_FILES['demo_package_zip'])) {
            throw new \Exception("File correct not setted!");
        }
        
        $demo_package_zip = $_FILES['demo_package_zip']['tmp_name'];
        if (!$wp_filesystem->is_file($demo_package_zip)) {
            throw new \Exception("Could not uploaded file");
        }
        
        $dump_dir = Config::getInstance()->getDemosDir();
        if (!$wp_filesystem->is_dir($dump_dir) && !wp_mkdir_p($dump_dir)) {
            throw new \Exception("No permission to create a directory");
        }
        
        unzip_file($demo_package_zip, $dump_dir);
    }
}