<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

/* @var $Demo \DM\Demo */

$ChangeDemoPage = \DM\Pages\ChangeDemo::getInstance();
$Config = \DM\Config::getInstance();

?>

<div class="demo">
    
    <?php if ($Demo->isActivated()) : ?>
    <div class="active-label">
        <?php esc_html_e('active', 'dm'); ?>
    </div>
    <?php endif; ?>
    
    <div class="preview">
        <?php if ($Config->isDevelopMode()) : ?>
            <div class="identety">
                <?php foreach ($Demo->toArray() as $key => $value): ?>
                    <?php echo esc_html($key); ?>: <b><?php echo esc_html($value); ?></b><br>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>
        
        <?php if ($Demo->getStatus()) : ?>
            <div class="status <?php echo esc_attr($Demo->getStatus()); ?>"><?php echo esc_html($Demo->getStatus()); ?></div>
        <?php endif; ?>

        <?php if ($Demo->getPreviewLink() && $Demo->getScreenshotUrl()) { ?>
            <a href="<?php echo $Demo->getPreviewLink(); ?>" target="_blank">
                <img src="<?php echo $Demo->getScreenshotUrl(); ?>" class="demo-promo">
            </a>
        <?php } else if ($Demo->getScreenshotUrl()) { ?>
            <img src="<?php echo $Demo->getScreenshotUrl(); ?>" class="demo-promo">
        <?php } else if ($Demo->getPreviewLink()) { ?>
            <a href="<?php echo $Demo->getPreviewLink(); ?>" target="_blank">
                <div class="demo-promo-no-img"><?php echo esc_html($Demo->getTitle()); ?></div>
            </a>
        <?php } else { ?>
            <div class="demo-promo-no-img"><?php echo esc_html($Demo->getTitle()); ?></div>
        <?php } ?>
        <div class="clearfix"></div>
    </div>
    
    <div class="clearfix"></div>
    
    <div class="content">
        
        <?php if ($description = $Demo->getDescription()) : ?>
            <p><?php echo esc_html($description); ?></p>
        <?php endif; ?>

        <!-- Installations notices -->
        <?php if (!$Demo->isCurrentThemeDemo()) { ?>
            <p class="warning">
                <i class="fa fa-exclamation-triangle" aria-hidden="true"></i> 
                <?php echo sprintf(esc_html__('This demo required theme %s', 'dm'), $Demo->getTemplateName()); ?>
            </p>
        <?php } else if (!$Demo->isCompatibleCurrentThemeVersion()) { ?>
            <p class="warning">
                <i class="fa fa-exclamation-triangle" aria-hidden="true"></i> 
                <?php echo sprintf(esc_html__('Your template must be version %s or higher.', 'dm'), $Demo->getTemplateVersion()); ?>
            </p>
        <?php } else if ($required_plugins) { ?>
            <p class="warning">
                <i class="fa fa-exclamation-triangle" aria-hidden="true"></i> 
                <?php echo sprintf(esc_html__('Next plugins must be installed: %s.', 'dm'), implode(', ', $required_plugins)); ?>
            </p>
        <?php } ?>
        
        <!-- Upload notices -->
        <?php if ($Demo->version === \DM\Manager::REMOUTE && !$Demo->isHaveFreeDiskSpace()) : ?>
            <p class="warning">
                <i class="fa fa-exclamation-triangle" aria-hidden="true"></i> 
                <?php echo sprintf(esc_html__('Not enough free space (total: %s MB), you need at least %s MB or higher.', 'dm'), \DM\Service::getFreeSpace(), $Demo->getMinFreeSpaceSize()); ?>
            </p>
        <?php endif; ?>
            
    </div>
    <div class="actions">
        
        <div class="btn-group">
        
            <?php if (!$Demo->isCurrentThemeDemo() && !$Config->isDevelopMode()) : ?>
            
                <?php if ($Demo->getPreviewLink()) : ?>
                    <a href="<?php echo $Demo->getPreviewLink(); ?>" target="_blank" class="btn btn-default"><i class="fa fa-eye" aria-hidden="true"></i> preview</a>
                <?php endif; ?>

                <?php if ($Demo->getMarketLink()) : ?>
                    <a href="<?php echo $Demo->getMarketLink(); ?>" target="_blank" class="btn btn-default buy"><i class="fa fa-shopping-cart" aria-hidden="true"></i> buy on envato</a>
                <?php endif; ?>
            
            <?php else: ?>
            
                <?php include 'demo-actions.php'; ?>
                    
            <?php endif; ?>
        </div>
                
        <div class="clearfix"></div>
    </div>
</div>
